@@ -43,6 +43,7 @@ class KRUNNER_EXPORT RunnerManager : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QStringList history READ history)
+    Q_PROPERTY(bool querying READ querying NOTIFY queryingChanged)
     Q_PROPERTY(bool historyEnabled READ historyEnabled WRITE setHistoryEnabled NOTIFY historyEnabledChanged)
 
 public:
@@ -52,7 +53,7 @@ public:
      * @param stateGroup Config group used for storing history
      * @since 6.0
      */
-    explicit RunnerManager(const KConfigGroup &pluginConfigGroup, KConfigGroup stateGroup, QObject *parent);
+    explicit RunnerManager(const KConfigGroup &pluginConfigGroup, const KConfigGroup &stateGroup, QObject *parent);
 
     /**
      * Constructs a RunnerManager using the default locations for state/plugin config
@@ -127,6 +128,12 @@ public:
      */
     bool historyEnabled();
 
+    /**
+     * If the RunnerManager is currently querying
+     * @since 6.7
+     */
+    bool querying() const;
+
     /**
      * Enables/disabled the history feature for the RunnerManager instance.
      * The value will not be persisted and is only kept during the object's lifetime.
@@ -223,6 +230,13 @@ Q_SIGNALS:
      */
     void queryFinished();
 
+    /**
+     * Emitted when the querying status has changed
+     * @since 6.7
+     */
+
+    void queryingChanged();
+
     /**
      * Put the given search term in the KRunner search field
      * @param term The term that should be displayed
